| CoefVar | R Documentation |
The R6 class CoefVar for the coefficient of variation
(cv)
x |
An |
na.rm |
a logical value indicating whether |
digits |
integer indicating the number of decimal places to be used. |
The cv
is a measure of relative dispersion representing the degree of variability
relative to the mean [1]. Since cv is unitless, it is useful
for comparison of variables with different units. It is also a measure of
homogeneity [1].
[1] Albatineh, AN., Kibria, BM., Wilcox, ML., & Zogheib,
B, 2014, Confidence interval estimation for the population coefficient of
variation using ranked set sampling: A simulation study, Journal of Applied
Statistics, 41(4), 733–751, DOI:
\Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/02664763.2013.847405")}
x <- c(
0.2, 0.5, 1.1, 1.4, 1.8, 2.3, 2.5, 2.7, 3.5, 4.4,
4.6, 5.4, 5.4, 5.7, 5.8, 5.9, 6.0, 6.6, 7.1, 7.9
)
CoefVar$new(x)$est()
cv_x <- CoefVar$new(x, digits = 2)
cv_x$est()
cv_x$est_corr()
R6::is.R6(cv_x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.